# -*- coding: utf-8 -*-
"""
# ---------------------------------------------------------------------------------------------------------
# ProjectName:  qlvClient
# FileName:     config.py
# Description:  TODO
# Author:       GIGABYTE
# CreateDate:   2024/04/17
# Copyright ©2011-2024. Hunan xxxxxxx Company limited. All rights reserved.
# ---------------------------------------------------------------------------------------------------------
"""

qvl_map = {
    "user_id": 186,
    "user_key": "9a68295ec90b1fc10ab94331c882bab9",
    "domain": "outsideapi.qlv88.com",
    "protocol": "http",
    "interfaces": {
        "lock_order": {
            "path": "/LockOrder.ashx",
            "method": "post"
        },
        "unlock_order": {
            "path": "/OrderUnlock.ashx",
            "method": "post"
        },
        "write_order_log_new": {
            "path": "/OrderLogWriteNew.ashx",
            "method": "post"},
        "save_order_pay_info": {
            "path": "/OrderPayInfoSave.ashx",
            "method": "post"},
        "fill_order_itinerary_info": {
            "path": "/BackfillTicketNumberNew.ashx",
            "method": "post"
        }
    }
}



# -*- coding: utf-8 -*-
"""
# ---------------------------------------------------------------------------------------------------------
# ProjectName:  qlvClient
# FileName:     test.py
# Description:  TODO
# Author:       GIGABYTE
# CreateDate:   2024/04/17
# Copyright ©2011-2024. Hunan xxxxxxx Company limited. All rights reserved.
# ---------------------------------------------------------------------------------------------------------
"""
from qlv_client.proxy import QlvService


def test_lock_order():
    xc = {
        "policy_name": "XCAPP出票",
        "oper": "robot-XCAPP",
        "air_cos": "",
        "order_pk": "",
        "order_src_cat": "国内"
    }
    QlvService.get_lock_order(xc)


def test_unlock_order():
    QlvService.set_unlock_order(
        order_id=1234567890, oper="robot-XC", order_state="0", order_lose_type="政策", remark="价格不符"
    )


def test_save_pay_info():
    kwargs = {
        "pre_order_id": 1232132131231231,
        "payment_time": "2024-04-10 19:46:00",
        "out_pf": "XCAPP",
        "out_ticket_account": "K王总信用卡",
        "pay_account_type": "K王总信用卡",
        "pay_account": "浦发7397",
        "payment_amount": 1000,
        "ctrip_order_id": "2342342342342342",
        "passenger": "徐婷婷,顾欣桐",
        "oper": "robot-XC",
        "ctrip_username": "18600440822",
        "user_pass": "ca161022",
    }
    QlvService.save_pay_info(**kwargs)


def test_fill_order_itinerary_info():
    kwargs = {
        "pre_order_id": 1232132131231231,
        "oper": "robot-XC",
        "card_id": "12312312312",
        "passenger": "牛婷婷",
        "arrive_city": "CSH",
        "itinerary_id": "831-111212121",
        "departure_city": "SZG"
    }
    QlvService.save_itinerary_info(**kwargs)


if __name__ == "__main__":
    import logging
    from qlv_client.utils import logger

    logger.setLevel(level=logging.DEBUG)
    logger.addHandler(logging.StreamHandler())
    logger.info("开始打印....")
    test_lock_order()
    test_unlock_order()
    test_save_pay_info()
    test_fill_order_itinerary_info()
    # test_fill_order_itinerary_info()



# -*- coding: utf-8 -*-
"""
# ---------------------------------------------------------------------------------------------------------
# ProjectName:  qlvClient
# FileName:     proxy.py
# Description:  TODO
# Author:       GIGABYTE
# CreateDate:   2024/04/17
# Copyright ©2011-2024. Hunan xxxxxxx Company limited. All rights reserved.
# ---------------------------------------------------------------------------------------------------------
"""
import typing as t

from qlv_client.utils import logger
from qlv_client.api import OrderService
from qlv_client.repository import QlvConfigRepository


class QlvService(object):

    @classmethod
    def get_lock_order(cls, lock_order_params: dict) -> t.Dict:
        logger.info("根据政策匹配，开始获取劲旅系统被锁定的订单...")
        kwargs = QlvConfigRepository.get_request_base_params(inter_name="lock_order")
        kwargs.update(lock_order_params)
        order_ser = OrderService(**QlvConfigRepository.get_host_params())
        result = order_ser.lock_order(**kwargs)
        result["policy_args"] = lock_order_params
        result["data_info"] = result.pop("datainfojson", None)
        return result

    @classmethod
    def set_unlock_order(cls, order_id: int, oper: str, order_state: str, order_lose_type: str, remark: str) -> bool:
        logger.info("出票{}，开始解锁劲旅平台订单<{}>".format("成功" if order_state == "1" else "失败", order_id))
        kwargs = QlvConfigRepository.get_request_base_params(inter_name="unlock_order")
        unlock_order_params = QlvConfigRepository.get_unlock_order_params(
            order_id=order_id, oper=oper, order_state=order_state, order_lose_type=order_lose_type, remark=remark
        )
        kwargs.update(unlock_order_params)
        order_ser = OrderService(**QlvConfigRepository.get_host_params())
        result = order_ser.unlock_order(**kwargs)
        if result.get("code") == 1:
            logger.info("劲旅平台订单<{}>解锁成功.".format(order_id))
            return True
        else:
            logger.error("劲旅平台订单<{}>解锁失败，返回：{}".format(order_id, result))
            return False

    @classmethod
    def unlock_reason_with_flag(cls, flag: bool, order_id: int, oper: str, remark: str) -> bool:
        unlock_reason_params = QlvConfigRepository.get_unlock_reason_params(
            flag=flag, order_id=order_id, oper=oper, remark=remark
        )
        return cls.set_unlock_order(**unlock_reason_params)

    @classmethod
    def loop_unlock_reason_with_flag(cls, flag: bool, order_id: int, oper: str, remark: str, attempts: int = 3):
        # 尝试3次解锁
        for i in range(attempts):
            is_succeed = QlvService.unlock_reason_with_flag(flag=flag, order_id=order_id, oper=oper, remark=remark)
            if is_succeed is True:
                break

    @classmethod
    def save_pay_info(cls, **kwargs) -> bool:
        logger.info("开始向劲旅系统回填采购信息...")
        args = QlvConfigRepository.get_request_base_params(inter_name="save_order_pay_info")
        order_pay_info = QlvConfigRepository.get_order_pay_info(**kwargs)
        args.update(order_pay_info)
        order_ser = OrderService(**QlvConfigRepository.get_host_params())
        result = order_ser.save_order_pay_info(**args)
        if result.get("code") == 0:
            logger.error("向劲旅系统回填采购信息失败，返回：{}".format(result))
            return False
        else:
            logger.error("向劲旅系统回填采购信息成功.")
            return True

    @classmethod
    def save_itinerary_info(cls, **kwargs) -> bool:
        logger.info("开始向劲旅系统回填乘客票单信息...")
        args = QlvConfigRepository.get_request_base_params(inter_name="fill_order_itinerary_info")
        order_itinerary_info = QlvConfigRepository.get_order_itinerary_info(**kwargs)
        args.update(order_itinerary_info)
        order_ser = OrderService(**QlvConfigRepository.get_host_params())
        result = order_ser.fill_order_itinerary_info(**args)
        if result.get("code") == 0:
            logger.error("向劲旅系统回填乘客票单信息失败，返回：{}".format(result))
            return False
        else:
            logger.error("向劲旅系统回填乘客票单信息成功.")
            return True

    @classmethod
    def save_itinerary_info_by_batch_itinerary(cls, pre_order_id: int, oper: str, itinerary_info: list) -> bool:
        logger.info("开始向劲旅系统回填乘客票单信息...")
        args = QlvConfigRepository.get_request_base_params(inter_name="fill_order_itinerary_info")
        ticket_infos = list()
        for info in itinerary_info:
            passenger = info.get("passenger")
            card_id = info.get("card_id")
            itinerary_id = info.get("itinerary_id")
            if itinerary_id:
                departure_city = info.get("departure_city")
                arrive_city = info.get("arrive_city")
                val: str = "#".join([passenger, card_id, itinerary_id, departure_city, arrive_city])
                ticket_infos.append(val)
        if ticket_infos:
            order_itinerary_info = {
                "order_id": pre_order_id,
                "oper": oper,
                "ticket_infos": ";".join(ticket_infos)
            }
            args.update(order_itinerary_info)
            order_ser = OrderService(**QlvConfigRepository.get_host_params())
            result = order_ser.fill_order_itinerary_info(**args)
            if result.get("code") == 0:
                logger.error("向劲旅系统回填乘客票单信息失败，返回：{}".format(result))
                return False
            else:
                logger.info("向劲旅系统回填乘客票单信息成功.")
                return True
        else:
            return False

    @classmethod
    def save_new_log(cls, pre_order_id: int, oper: str, logs: str) -> bool:
        logger.info("开始向劲旅系统给订单<{}>记录新日志...".format(pre_order_id))
        args = QlvConfigRepository.get_request_base_params(inter_name="write_order_log_new")
        args.update(dict(order_id=pre_order_id, oper=oper, logs=logs))
        order_ser = OrderService(**QlvConfigRepository.get_host_params())
        result = order_ser.write_order_log_new(**args)
        if result.get("code") == 0:
            logger.error("向劲旅系统给订单<{}>记录新日志失败...".format(pre_order_id))
            return False
        else:
            logger.info("向劲旅系统给订单<{}>记录新日志成功.".format(pre_order_id))
            return True



# -*- coding: utf-8 -*-
"""
# ---------------------------------------------------------------------------------------------------------
# ProjectName:  qlvClient
# FileName:     utils.py
# Description:  TODO
# Author:       GIGABYTE
# CreateDate:   2024/04/17
# Copyright ©2011-2024. Hunan xxxxxxx Company limited. All rights reserved.
# ---------------------------------------------------------------------------------------------------------
"""
import re
import hashlib
import logging
from datetime import datetime, timedelta

logger = logging.getLogger("root")

standard_date_format = "%Y-%m-%d %H:%M:%S"


def iso_to_standard_datestr(datestr: str, time_zone_step: int) -> str:
    """iso(2024-04-21T04:20:00Z)格式转 标准的时间格式(2024-01-01 00:00:00)"""
    dt_str = "{} {}".format(datestr[:10], datestr[11:-1])
    dt = datetime.strptime(dt_str, standard_date_format)
    dt_step = dt + timedelta(hours=time_zone_step)
    return dt_step.strftime(standard_date_format)


def current_datetime_str() -> str:
    return datetime.now().strftime(standard_date_format)


def encryp_md5(data: str) -> str:
    # 创建一个 hashlib.md5 对象
    md5_hash = hashlib.md5()
    # 将输入的字符串转换为 bytes，并更新 MD5 哈希对象
    md5_hash.update(data.encode())
    # 获取 MD5 值的十六进制表示形式（32 位小写）
    md5_hex_digest = md5_hash.hexdigest()
    return md5_hex_digest


def covert_dict_key_to_lower(d: dict) -> dict:
    result = dict()
    for key, value in d.items():
        if isinstance(key, str):
            key_new = key.lower()
            result[key_new] = value
    return result


def get_html_title(html: str) -> str:
    # 使用正则表达式提取目标字符串
    pattern = '<title>(.*?)</title>'
    match = re.search(pattern, html)
    if match:
        title = match.group(1)
    else:
        title = "Abnormal HTML document structure"
    return title



# -*- coding: utf-8 -*-
"""
# ---------------------------------------------------------------------------------------------------------
# ProjectName:  qlvClient
# FileName:     api.py
# Description:  TODO
# Author:       GIGABYTE
# CreateDate:   2024/04/17
# Copyright ©2011-2024. Hunan xxxxxxx Company limited. All rights reserved.
# ---------------------------------------------------------------------------------------------------------
"""
import typing as t

from qlv_client.utils import encryp_md5, logger
from qlv_client.http_client import HttpService


class OrderService(object):

    def __init__(self, domain: str, protocol: str) -> None:
        self.__http_client = HttpService(domain=domain, protocol=protocol)

    @classmethod
    def __gen_sign_key(cls, user_key: str, request_data: t.Dict) -> str:
        # 对字典按照键进行排序
        sorted_keys = sorted(request_data.keys())
        result = []
        for key in sorted_keys:
            value = request_data[key]
            if value == "" or value is None:
                result.append("{}=".format(key))  # 当值为空串时，使用 key=
            else:
                result.append("{}={}".format(key, value))  # 当值不为空串时，使用 key=value
        result.append(user_key)
        # 使用空格连接所有拼接结果
        concatenated_string = "".join(result)
        logger.info('用于签名的拼接字符串为："{}"'.format(concatenated_string))
        return encryp_md5(concatenated_string)

    def lock_order(
            self,
            path: str,
            method: str,
            user_key: str,
            user_id: int,
            policy_name: str,
            oper: str,
            air_cos: str = None,
            order_pk: str = None,
            order_src_cat: str = None
    ) -> t.Dict:
        """
        订单锁定
        :params path str: 接口路径
        :params method str: 请求方法
        :params user_key str: 劲旅系统认证用户key
        :params user_id str: 劲旅系统认证用户id
        :params policy_name str: 政策名称关键字
        :params oper str: 操作锁单人，机器人名称
        :params air_cos str: 航司
        :params order_pk str: 劲旅订单号，指定订单号锁单
        :params order_src_cat str: 订单类别，国内/国际
        return t.Dict
        """
        request_data = {
            "policyName": policy_name,
            "airCos": air_cos or "",
            "orderPK": order_pk or "",
            "orderSrcCat": order_src_cat or "",
            "oper": oper
        }
        sign_key = self.__gen_sign_key(user_key=user_key, request_data=request_data)
        json = {
            "UserId": user_id,
            "SignKey": sign_key,
            "requestData": request_data,
        }
        return self.__http_client.send_request(method=method, path=path, json=json)

    def unlock_order(
            self,
            path: str,
            method: str,
            user_key: str,
            user_id: int,
            order_id: int,
            oper: str,
            order_state: str,
            order_lose_type: str,
            remark: str = None
    ) -> t.Dict:
        """
        订单解锁
        :params path str: 接口路径
        :params method str: 请求方法
        :params user_key str: 劲旅系统认证用户key
        :params user_id str: 劲旅系统认证用户id
        :params order_id str: 劲旅系统订单号
        :params oper str: 操作人,机器人名称
        :params order_state str: 出票状态，0:出票失败,1出票成功
        :params order_lose_type str: 出票失败类别，户自定义失败类别,比如:政策,系统等等
        :params remark str: 备注，例如：价格不符
        return t.Dict
        """
        request_data = {
            "orderID": order_id,
            "oper": oper,
            "remark": remark or "",
            "orderState": order_state,
            "orderLoseType": order_lose_type,
        }
        sign_key = self.__gen_sign_key(user_key=user_key, request_data=request_data)
        json = {
            "UserId": user_id,
            "SignKey": sign_key,
            "requestData": request_data,
        }
        return self.__http_client.send_request(method=method, path=path, json=json)

    def write_order_log_new(
            self,
            path: str,
            method: str,
            user_key: str,
            user_id: int,
            order_id: int,
            oper: str,
            logs: str
    ) -> t.Dict:
        """
        订单日志回写
        :params path str: 接口路径
        :params method str: 请求方法
        :params user_key str: 劲旅系统认证用户key
        :params user_id str: 劲旅系统认证用户id
        :params order_id str: 劲旅系统订单号
        :params oper str: 操作人,机器人名称
        :params logs str: 日志内容
        return t.Dict
        """
        request_data = {
            "orderID": order_id,
            "oper": oper,
            "logs": logs
        }
        sign_key = self.__gen_sign_key(user_key=user_key, request_data=request_data)
        json = {
            "UserId": user_id,
            "SignKey": sign_key,
            "requestData": request_data,
        }
        return self.__http_client.send_request(method=method, path=path, json=json)

    def save_order_pay_info(
            self,
            path: str,
            method: str,
            user_key: str,
            user_id: int,
            order_id: int,
            oper: str,
            payment_time: str,
            out_pf: str,
            out_ticket_account: str,
            pay_account_type: str,
            pay_account: str,
            money: str,
            serial_number: str,
            air_co_order_id: str,
            pnames: str,
            d_type: int,
            remark: str = None
    ) -> t.Dict:
        """
        采购信息回填
        :params path str: 接口路径
        :params method str: 请求方法
        :params user_key str: 劲旅系统认证用户key
        :params user_id str: 劲旅系统认证用户id
        :params order_id str: 劲旅系统订单号
        :params oper str: 操作人,机器人名称
        :params pay_time str: 支付时间，对应前端页面的【采购日期】
        :params out_pf str: 出票平台，对应前端页面的【出票平台】
        :params out_ticket_account str: 出票账号，对应前端页面的【出票账号】
        :params pay_account_type str: 支付账号类型，对应前端页面的【采购账号类型】
        :params pay_account str: 支付账号，对应前端页面的【采购账号】
        :params money str: 金额，对应前端页面的【采购金额】
        :params serial_number str: 流水号，对应前端页面的【对账标识】
        :params air_co_order_id str: 官网订单号，对应前端页面的【官网订单号】
        :params pnames str: 乘机人姓名，对应前端页面的【采购乘客】
        :params d_type int: 类型，1支付单程,2支付往返,3支付多程
        :params remark str: 备注说明，对应前端页面的【备注】
        return t.Dict
        """
        request_data = {
            "orderID": order_id,
            "payTime": payment_time,
            "outPF": out_pf,
            "outTicketAccount": out_ticket_account,
            "payAccountType": pay_account_type,
            "payAccount": pay_account,
            "money": money,
            "serialNumber": serial_number,
            "airCoOrderID": air_co_order_id,
            "pnames": pnames,
            "oper": oper,
            "remark": remark,
            "type": d_type,
        }
        sign_key = self.__gen_sign_key(user_key=user_key, request_data=request_data)
        json = {
            "UserId": user_id,
            "SignKey": sign_key,
            "requestData": request_data,
        }
        return self.__http_client.send_request(method=method, path=path, json=json)

    def fill_order_itinerary_info(
            self,
            path: str,
            method: str,
            user_key: str,
            user_id: int,
            order_id: int,
            oper: str,
            ticket_infos: str
    ) -> t.Dict:
        """
        订单票号回填
        :params path str: 接口路径
        :params method str: 请求方法
        :params user_key str: 劲旅系统认证用户key
        :params user_id str: 劲旅系统认证用户id
        :params order_id str: 劲旅系统订单号
        :params oper str: 操作人,机器人名称
        :params ticket_infos str: 乘机人票号信息，格式如：乘机人1#证件号1#票号1#起飞#到达;乘机人2#证件号2#票号2#起飞#到达
        return t.Dict
        """
        request_data = {
            "orderID": order_id,
            "oper": oper,
            "ticketInfos": ticket_infos
        }
        sign_key = self.__gen_sign_key(user_key=user_key, request_data=request_data)
        json = {
            "UserId": user_id,
            "SignKey": sign_key,
            "requestData": request_data,
        }
        return self.__http_client.send_request(method=method, path=path, json=json)



# -*- coding: utf-8 -*-
"""
# ---------------------------------------------------------------------------------------------------------
# ProjectName:  qlvClient
# FileName:     repository.py
# Description:  TODO
# Author:       GIGABYTE
# CreateDate:   2024/04/17
# Copyright ©2011-2024. Hunan xxxxxxx Company limited. All rights reserved.
# ---------------------------------------------------------------------------------------------------------
"""
from qlv_client.config import qvl_map


class QlvConfigRepository(object):

    @classmethod
    def get_request_base_params(cls, inter_name: str) -> dict:
        return {
            "path": qvl_map.get("interfaces").get(inter_name).get("path"),
            "method": qvl_map.get("interfaces").get(inter_name).get("method"),
            "user_key": qvl_map.get("user_key"),
            "user_id": qvl_map.get("user_id")
        }

    @classmethod
    def get_host_params(cls) -> dict:
        return dict(domain=qvl_map.get("domain"), protocol=qvl_map.get("protocol"))

    @classmethod
    def get_unlock_order_params(cls, **kwargs) -> dict:
        return {
            "order_id": kwargs.get("order_id"),
            "oper": kwargs.get("oper"),
            "order_state": kwargs.get("order_state"),
            "order_lose_type": kwargs.get("order_lose_type"),
            "remark": kwargs.get("remark")
        }

    @classmethod
    def get_unlock_reason_params(cls, flag: bool, order_id: int, oper: str, remark: str) -> dict:
        """flag 为 true时，出票成功，反之出票失败"""
        return dict(
            order_id=order_id,
            oper=oper,
            order_state="1" if flag is True else "0",
            order_lose_type="解锁订单",
            remark=remark
        )

    @classmethod
    def get_order_pay_info(cls, **kwargs) -> dict:
        return {
            "order_id": kwargs.get("pre_order_id"),
            "payment_time": kwargs.get("payment_time"),
            "out_pf": kwargs.get("out_pf"),
            "out_ticket_account": kwargs.get("out_ticket_account"),
            "pay_account_type": kwargs.get("pay_account_type"),
            "pay_account": kwargs.get("pay_account"),
            "money": kwargs.get("payment_amount"),
            "serial_number": kwargs.get("ctrip_order_id"),
            "air_co_order_id": kwargs.get("ctrip_order_id"),
            "pnames": kwargs.get("passenger"),
            "oper": kwargs.get("oper"),
            "remark": "{}-{}".format(kwargs.get("ctrip_username"), kwargs.get("user_pass")),
            "d_type": 1
        }

    @classmethod
    def get_order_itinerary_info(cls, **kwargs) -> dict:
        card_id = kwargs.get("card_id")
        passenger = kwargs.get("passenger")
        arrive_city = kwargs.get("arrive_city")
        itinerary_id = kwargs.get("itinerary_id")
        departure_city = kwargs.get("departure_city")
        return {
            "order_id": kwargs.get("pre_order_id"),
            "oper": kwargs.get("oper"),
            "ticket_infos": "#".join([passenger, card_id, itinerary_id, departure_city, arrive_city])
        }



# -*- coding: utf-8 -*-
"""
# ---------------------------------------------------------------------------------------------------------
# ProjectName:  qlvClient
# FileName:     setup.py
# Description:  TODO
# Author:       GIGABYTE
# CreateDate:   2024/04/17
# Copyright ©2011-2024. Hunan xxxxxxx Company limited. All rights reserved.
# ---------------------------------------------------------------------------------------------------------
"""
from setuptools import setup, find_packages

setup(
    name='qlv-client',
    version='0.1.8',
    description='This is my qlv proxy qlv_client package',
    long_description='This is my qlv proxy qlv_client package',
    author='ckf10000',
    author_email='ckf10000@sina.com',
    url='https://github.com/ckf10000/qlvClient',
    packages=find_packages(),
    install_requires=[
        'requests>=2.31.0'
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)



# -*- coding: utf-8 -*-
"""
# ---------------------------------------------------------------------------------------------------------
# ProjectName:  qlvClient
# FileName:     converter.py
# Description:  TODO
# Author:       GIGABYTE
# CreateDate:   2024/04/17
# Copyright ©2011-2024. Hunan xxxxxxx Company limited. All rights reserved.
# ---------------------------------------------------------------------------------------------------------
"""
from decimal import Decimal
from utils import iso_to_standard_datestr


class QlvRequestParamsConverter(object):

    @classmethod
    def covert_flight_info(cls, order_id: int, flights: dict) -> dict:
        flight_info = dict(
            pre_order_id=order_id,
            departure_time=iso_to_standard_datestr(datestr=flights.get("DatDep"), time_zone_step=8),
            departure_city=flights.get("CodeDep"),
            departure_city_name=flights.get("CityDep"),
            arrive_time=iso_to_standard_datestr(datestr=flights.get("DatArr"), time_zone_step=8),
            arrive_city=flights.get("CodeArr"),
            arrive_city_name=flights.get("CityArr"),
            flight=flights.get("FlightNo"),
            pre_sale_amount=str(Decimal(flights.get("PriceStd")))
        )
        return flight_info



# -*- coding: utf-8 -*-
"""
# ---------------------------------------------------------------------------------------------------------
# ProjectName:  qlvClient
# FileName:     http_client.py
# Description:  TODO
# Author:       GIGABYTE
# CreateDate:   2024/04/17
# Copyright ©2011-2024. Hunan xxxxxxx Company limited. All rights reserved.
# ---------------------------------------------------------------------------------------------------------
"""
import requests
from qlv_client.utils import logger
from qlv_client.utils import covert_dict_key_to_lower, get_html_title


class HttpService(object):
    __time_out = 30
    __domain = None
    __url = None
    __protocol = None
    __headers: dict = {
        "Content-Type": "application/json; charset=UTF-8",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) " +
                      "Chrome/123.0.0.0 Safari/537.36"
    }

    def __init__(self, domain: str, protocol: str) -> None:
        self.__domain = domain
        self.__protocol = protocol

    def send_request(self, method: str, path: str, params: dict = None, data: dict = None, json: dict = None,
                     headers: dict = None) -> dict:
        if isinstance(headers, dict):
            self.__headers = headers
        self.__url = "{}://{}{}".format(self.__protocol, self.__domain, path)
        # 发送HTTP请求
        logger.info(
            "开始发起http请求，url: {}, 方法：{}，请求params参数：{}，请求headers参数：{}，请求data参数：{}，请求json参数：{}".format(
                self.__url,
                method,
                params or "{}",
                self.__headers,
                data or "{}",
                json or "{}",
            )
        )
        return self.__send_http_request(method=method, params=params, data=data, json=json)

    def __send_http_request(self, method: str, params: dict = None, data: dict = None,
                            json: dict = None) -> dict:
        # 实际发送HTTP请求的内部方法
        # 使用 requests 库发送请求
        method = method.lower().strip()
        if method in ("get", "post"):
            try:
                if method == "get":
                    response = requests.get(self.__url, params=params, verify=False, timeout=self.__time_out,
                                            headers=self.__headers)
                else:
                    response = requests.post(self.__url, params=params, json=json, data=data, verify=False,
                                             timeout=self.__time_out, headers=self.__headers)
                result = self.__parse_data_response(response=response)
            except Exception as e:
                logger.error("调用url<{}>异常，原因：{}".format(self.__url, str(e)))
                result = dict(code=500, message=str(e), data=dict())
        else:
            result = dict(code=400, message="Unsupported HTTP method: {}".format(
                method), data=dict())
        return result

    def __parse_data_response(self, response: requests.Response) -> dict:
        # 获取 Content-Type 头信息
        content_type = response.headers.get('Content-Type')
        # 判断返回的内容类型
        if 'application/json' in content_type or 'text/json' in content_type:
            # JSON 类型
            data = covert_dict_key_to_lower(d=response.json())
        elif 'text/plain' in content_type:
            # 纯文本类型
            data = dict(code=response.status_code, message=get_html_title(
                html=response.text), data=response.text)
        else:
            # 其他类型，默认视为二进制内容
            content = response.content.decode('utf-8')
            data = dict(code=response.status_code,
                        message=get_html_title(html=content), data=content)
        logger.info("调用url: {}的正常返回值为：{}".format(self.__url, data))
        return data
